@@ -23,16 +23,16 @@ from aliyunsdkobjectdet.endpoint import endpoint_data
 class DetectMainBodyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'objectdet', '2019-12-30', 'DetectMainBody','objectdet')
+		RpcRequest.__init__(self, 'objectdet', '2019-12-30', 'DetectMainBody')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ImageURL(self):
+	def get_ImageURL(self): # String
 		return self.get_query_params().get('ImageURL')
 
-	def set_ImageURL(self,ImageURL):
-		self.add_query_param('ImageURL',ImageURL)
\ No newline at end of file
+	def set_ImageURL(self, ImageURL):  # String
+		self.add_query_param('ImageURL', ImageURL)
